"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.installer = exports.createBinDir = exports.createTempDir = exports.createWorkDir = exports.getHomeDir = void 0;
const core = __importStar(require("@actions/core"));
const tc = __importStar(require("@actions/tool-cache"));
const io = __importStar(require("@actions/io"));
const get_os_1 = __importDefault(require("./get-os"));
const get_url_1 = __importDefault(require("./get-url"));
const path = __importStar(require("path"));
const constants_1 = require("./constants");
function getHomeDir() {
    let homedir = '';
    if (process.platform === 'win32') {
        homedir = process.env['USERPROFILE'] || 'C:\\';
    }
    else {
        homedir = `${process.env.HOME}`;
    }
    core.debug(`homeDir: ${homedir}`);
    return homedir;
}
exports.getHomeDir = getHomeDir;
function createWorkDir() {
    return __awaiter(this, void 0, void 0, function* () {
        const workDir = path.join(getHomeDir(), constants_1.Action.WorkDirName);
        yield io.mkdirP(workDir);
        core.debug(`workDir: ${workDir}`);
        return workDir;
    });
}
exports.createWorkDir = createWorkDir;
function createTempDir(workDir) {
    return __awaiter(this, void 0, void 0, function* () {
        const tempDir = path.join(workDir, constants_1.Action.TempDirName);
        yield io.mkdirP(tempDir);
        core.debug(`tempDir: ${tempDir}`);
        return tempDir;
    });
}
exports.createTempDir = createTempDir;
function createBinDir(workDir) {
    return __awaiter(this, void 0, void 0, function* () {
        const binDir = path.join(workDir, 'bin');
        yield io.mkdirP(binDir);
        core.addPath(binDir);
        core.debug(`binDir: ${binDir}`);
        return binDir;
    });
}
exports.createBinDir = createBinDir;
function installer(version) {
    return __awaiter(this, void 0, void 0, function* () {
        const osName = get_os_1.default(process.platform);
        core.debug(`Operating System: ${osName}`);
        const toolURL = get_url_1.default(osName, version);
        core.debug(`toolURL: ${toolURL}`);
        const workDir = yield createWorkDir();
        const binDir = yield createBinDir(workDir);
        const tempDir = yield createTempDir(workDir);
        console.log('toolURL', toolURL);
        const toolAssets = yield tc.downloadTool(toolURL);
        console.log('toolAssets', toolAssets);
        let toolBin = '';
        if (process.platform === 'win32') {
            const toolExtractedFolder = yield tc.extractZip(toolAssets, tempDir);
            toolBin = `${toolExtractedFolder}/${constants_1.Tool.CmdName}.exe`;
        }
        else {
            const toolExtractedFolder = yield tc.extractTar(toolAssets, tempDir);
            toolBin = `${toolExtractedFolder}/${constants_1.Tool.CmdName}`;
        }
        yield io.mv(toolBin, binDir);
    });
}
exports.installer = installer;
//# sourceMappingURL=installer.js.map